@@ -61,7 +61,7 @@ class LoginDialog(QDialog):
         self.setLayout(QVBoxLayout())
 
     @trace.method
-    def wait_for_lock(self, *_):
+    def wait_for_lock(self):
         """Start waiting for the steam instance lock asynchronously, and
         show/activate the window when we acquire the lock."""
         if self._exit:
@@ -92,7 +92,12 @@ class LoginDialog(QDialog):
     @trace.method
     def show_trayicon(self):
         """Create and show the tray icon."""
-        self.trayicon = QSystemTrayIcon(self.theme.window_icon)
+        # The conversion to QPixmap and back to QIcon is needed to prevent a
+        # bug that leads to the icon not being displayed in plasma. See:
+        # - https://github.com/coldfix/steam-acolyte/issues/8
+        # - https://bugreports.qt.io/browse/QTBUG-53550
+        icon = QIcon(self.theme.window_icon.pixmap(64))
+        self.trayicon = QSystemTrayIcon(icon)
         self.trayicon.setVisible(True)
         self.trayicon.setToolTip(
             "acolyte - lightweight steam account manager")
@@ -182,13 +187,13 @@ class LoginDialog(QDialog):
         menu.move(left, top)
 
     @trace.method
-    def exit_steam(self, *_):
+    def exit_steam(self):
         """Send shutdown command to steam."""
         self.stopAction.setEnabled(False)
         self.steam.stop()
 
     @trace.method
-    def _on_exit(self, *_):
+    def _on_exit(self):
         """Exit acolyte."""
         # We can't quit if steam is still running because QProcess would
         # terminate the child with us. In this case, we hide the trayicon and
@@ -257,6 +262,11 @@ def make_user_action(window, user):
     action.triggered.connect(lambda: window.login(user.account_name))
     action.setToolTip("Login {}".format(
         user.account_name or "new account"))
+    action.setToolTip(
+        "Set this user as the last active login, "
+        "restore login token if available, "
+        "and start steam." if user.persona_name else
+        "Start steam login dialog to enter a different user account.")
     action.setIcon(QIcon(
         theme.user_icon if user.account_name else theme.plus_icon))
     return action
@@ -300,10 +310,15 @@ class UserWidget(ButtonWidget):
         self.logout_action.triggered.connect(self.logout_clicked)
         self.logout_action.setIcon(self.theme.logout_icon)
         self.logout_action.setToolTip("Delete saved login")
+        self.logout_action.setWhatsThis(
+            "Logout user by deleting the saved login token.\n"
+            "The user will stay visible on this list.")
         self.delete_action = QAction()
         self.delete_action.triggered.connect(self.delete_clicked)
         self.delete_action.setIcon(theme.delete_icon)
         self.delete_action.setToolTip("Delete user from list")
+        self.delete_action.setWhatsThis(
+            "Logout and remove user from this list.")
         self.logout_button = QToolButton()
         self.logout_button.setDefaultAction(self.logout_action)
         self.delete_button = QToolButton()
